==> haskell-hslua-module-path-1.1.1-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-path
version:              1.1.1
visibility:           public
id:                   hslua-module-path-1.1.1-Izl26Hjiykl9aTHeThoENf
key:                  hslua-module-path-1.1.1-Izl26Hjiykl9aTHeThoENf
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  f37790490581d9ee28472c4a36f9c60f
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.1-Izl26Hjiykl9aTHeThoENf
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.1-DSJU8SYKYU4DnTGKMQUYFy
    hslua-marshalling-2.3.1-JxvDxLIULJe2WLCjIa0n8M
    hslua-packaging-2.3.1-1GOE82K1fCnBkcvXbt9ghV text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-path-1.1.1-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-path
version:              1.1.1
visibility:           public
id:                   hslua-module-path-1.1.1-TOkvoUJphY6sa4CqkSa1S
key:                  hslua-module-path-1.1.1-TOkvoUJphY6sa4CqkSa1S
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  6e4b25fe4cd8b8f78b3152eb17be2bc9
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.1-TOkvoUJphY6sa4CqkSa1S
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.1-DCimRFrkPNqLRhEWBh8kjB
    hslua-marshalling-2.3.1-D9bvzQC9qdoGgLxdUYWcYG
    hslua-packaging-2.3.1-70vkuVjDIQjBOxTeCEAoTh text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
